pub enum Flag {
C,
Z,
NC,
NZ,
}Expand description
Flags relevant to the operation of the instruction.
This flag is used to specify which flag the Opcode cares about, it is not used to indicate which flags an instruction may set.
For example, Opcode::Jp(Some(Flag::NZ), 0x1234) says that the instruction
is a Jp (jump) instruction that will jump to location 0x1234, if the NZ
(not zero) flag is set.
Variants
C
The Carry flag.
Z
The Zero Flag.
NC
The inverse of the Carry flag.
NZ
The inverse of the Zero flag.